@@ -28,18 +28,18 @@ module PDF
         @on_page_create_callback = nil
       end
 
-      attr_accessor :store, :version, :pages, :page, :trailer, :compress,
-        :encrypt, :encryption_key, :skip_encoding,
-        :before_render_callbacks, :on_page_create_callback
+      attr_accessor :store, :version, :pages, :page, :trailer, :compress, :encrypt, :encryption_key, :skip_encoding
+      attr_accessor :before_render_callbacks, :on_page_create_callback
 
       def populate_pages_from_store(document)
         return 0 if @store.page_count <= 0 || !@pages.empty?
 
         count = (1..@store.page_count)
-        @pages = count.map do |index|
-          orig_dict_id = @store.object_id_for_page(index)
-          PDF::Core::Page.new(document, object_id: orig_dict_id)
-        end
+        @pages =
+          count.map do |index|
+            orig_dict_id = @store.object_id_for_page(index)
+            PDF::Core::Page.new(document, object_id: orig_dict_id)
+          end
       end
 
       def normalize_metadata(options)
