@@ -2,9 +2,6 @@
 
 puts "PDF::Core specs: Running on Ruby Version: #{RUBY_VERSION}"
 
-require 'bundler'
-Bundler.setup
-
 if ENV['COVERAGE']
   require 'simplecov'
   SimpleCov.start
@@ -16,13 +13,15 @@ require 'rspec'
 require 'pdf/reader'
 require 'pdf/inspector'
 
+# rubocop: disable Style/SymbolProc
 RSpec.configure do |config|
   config.disable_monkey_patching!
 end
+# rubocop: enable Style/SymbolProc
 
 RSpec::Matchers.define :have_parseable_xobjects do
   match do |actual|
-    expect { PDF::Inspector::XObject.analyze(actual.render) }.not_to raise_error
+    expect { PDF::Inspector::XObject.analyze(actual.render) }.to_not raise_error
     true
   end
   failure_message_for_should do |actual|
